import './styles/global.css';

import React from 'react';

import { lang } from '../packages/localization/src/init';

import { Title, Subtitle, Description, Primary, Controls, Stories } from '@storybook/blocks';

export const multiLocalDecorator = (Story, context) => {
	const { locale } = context.globals;
	lang.setLocale(locale);
	return <Story />;
};

export const globalTypes = {
	locale: {
		name: 'Locale',
		defaultValue: 'en',
		toolbar: {
			icon: 'globe',
			showName: true,
			items: [
				{ value: 'en', right: '🇺🇸', title: 'English' },
				{ value: 'cs', right: '🇨🇿', title: 'Čeština' },
			],
		},
	},
};

export const decorators = [multiLocalDecorator];

export const parameters = {
	actions: {
		argTypesRegex: '^on[A-Z].*',
	},
	options: {
		storySort: {
			method: 'alphabetical',
			order: [
				'Introduction',
				'Auth',
				'Api',
				['Introduction'],
				'components',
				'Form',
				['Introduction', 'Implementation'],
				'Localization',
				['Introduction', 'Example'],
			],
		},
	},
	docs: {
		page: () => (
			<>
				<Title />
				<Subtitle />
				<Description />
				<Primary />
				<Controls />
				<Stories />
			</>
		),
	},
};
