import {
	BaseQueryApi,
	type BaseQueryFn,
	FetchArgs,
	fetchBaseQuery,
	type FetchBaseQueryError,
} from '@reduxjs/toolkit/query';
import { Mutex } from 'async-mutex';

export type BaseQueryArgs = Parameters<typeof fetchBaseQuery>[0];

const mutex = new Mutex();

export const baseQuery = (args: BaseQueryArgs) => fetchBaseQuery(args);

export const baseQueryWithReAuth: (
	args: BaseQueryArgs,
	when401: (api: BaseQueryApi) => Promise<void>,
) => BaseQueryFn<string | FetchArgs, unknown, FetchBaseQueryError> =
	(baseQueryArgs, when401) => async (args, api, extraOptions) => {
		await mutex.waitForUnlock();
		let result = await baseQuery(baseQueryArgs)(args, api, extraOptions);
		if (result.error?.status === 401) {
			if (!mutex.isLocked()) {
				const release = await mutex.acquire();
				try {
					await when401(api);
				} finally {
					release();
				}
			} else {
				await mutex.waitForUnlock();
				result = await baseQuery(baseQueryArgs)(args, api, extraOptions);
			}
		}
		return result;
	};
