import { useCallback } from 'react';
import { useDispatch } from 'react-redux';
import { useLocation } from 'wouter';

import { fetchTokens } from '../actions';
import { setAuthAttributes } from '../slice';
import { UseLoginParams } from '../types';

export const useFetchTokens = ({ baseUrl, clientId, tokenEndpoint, redirectUri }: UseLoginParams) => {
	const dispatch = useDispatch<any>();

	const [, setLocation] = useLocation();

	return useCallback(async (code: string) => {
		const { data: tokens } = await fetchTokens({
			baseUrl,
			tokenEndpoint,
			clientId,
			redirectUri: redirectUri,
			code,
		});
		if (tokens) {
			dispatch(
				setAuthAttributes({
					authenticated: true,
					accessToken: tokens.access_token,
					refreshToken: tokens.refresh_token,
					idToken: tokens.id_token,
					accessExpiresIn: tokens.expires_in,
					refreshExpiresIn: tokens.refresh_expires_in,
					sessionState: tokens.session_state,
				}),
			);
			setLocation('/');
		}
	}, []);
};
