import React, { FC, ReactNode } from 'react';
import clsx from 'clsx';

import { CalendarLayoutEnum, CalendarTypeEnum } from './Calendar';
import { CalendarDay, CalendarDayProps } from './CalendarDay';

export type CalendarCellProps = {
	Day?: FC<CalendarDayProps>;
	children?: ReactNode;
	className?: string;
	date: Date;
	enableHover?: boolean;
	isSelected?: boolean;
	isToday?: boolean;
	layout?: CalendarLayoutEnum;
	onClick?: (date: Date) => void;
	type?: CalendarTypeEnum;
	weekOfMonth?: number;
	workDate: Date;
};

export const CalendarCell: FC<CalendarCellProps> = ({ children, className, type, Day = CalendarDay, ...others }) => {
	return (
		<div
			className={clsx(
				{
					...(type === CalendarTypeEnum.days && {
						'calendar-cell-typeDay': true,
					}),
					...(type === CalendarTypeEnum.weeks && {
						'calendar-cell-typeWeek': true,
					}),
					...(type === CalendarTypeEnum.months && {
						'calendar-cell-typeMonth': true,
					}),
				},
				'calendar-cell',
				className
			)}>
			<Day {...others} type={type}>
				{children}
			</Day>
		</div>
	);
};
