import React, { FC, ReactNode } from 'react';
import clsx from 'clsx';
import { isSameMonth } from 'date-fns';

import { CalendarTypeEnum } from './Calendar';

export type CalendarDayProps = {
	children?: ReactNode;
	className?: string;
	date: Date;
	enableHover?: boolean;
	isSelected?: boolean;
	isToday?: boolean;
	onClick?: (date: Date) => void;
	type?: CalendarTypeEnum;
	workDate: Date;
};

export const CalendarDay: FC<CalendarDayProps> = ({
	enableHover,
	isSelected,
	isToday,
	onClick,
	children,
	date,
	className,
	workDate,
	type,
}) => {
	const isOtherMonth = !isSameMonth(workDate, date);
	return (
		<div
			className={clsx('calendar-day', className, {
				'calendar-day--selected': isSelected,
				'calendar-day--today': isToday,
				'calendar-day--hover': enableHover,
				...(type === CalendarTypeEnum.days && {
					'calendar-day--otherMonth': isOtherMonth,
				}),
				...(type === CalendarTypeEnum.weeks && {
					'calendar-day--otherMonth': isOtherMonth,
				}),
				...(type === CalendarTypeEnum.months && {}),
			})}
			onClick={() => onClick?.(date)}>
			{children}
		</div>
	);
};
