import React, { FC } from 'react';

import { CalendarLayoutEnum } from './Calendar';

export const WeekDaysShort: string[] = ['po', 'út', 'st', 'čt', 'pá', 'so', 'ne'];
export const WeekDaysLong: string[] = ['pondělí', 'úterý', 'středa', 'čtvrtek', 'pátek', 'sobota', 'neděle'];

export type CalendarDaysProps = {
	layout: CalendarLayoutEnum;
	longDayNames?: boolean;
	workDate: Date;
};

export const CalendarDays: FC<CalendarDaysProps> = ({ workDate, layout, longDayNames }) => {
	const dayOfWeek = new Date(workDate).getDay() === 0 ? 6 : new Date(workDate).getDay() - 1;
	let daysInWeekNames = WeekDaysShort;
	if (longDayNames) daysInWeekNames = WeekDaysLong;
	if (layout === CalendarLayoutEnum.day) daysInWeekNames = [WeekDaysLong[dayOfWeek]];
	return (
		<div className="calendar-row calendar-days table-row">
			{daysInWeekNames.map((day) => (
				<div className="calendar-cell table-cell" key={day}>
					{day}
				</div>
			))}
		</div>
	);
};
