import React, { FC } from 'react';
import { compose, mapObjIndexed, values } from 'ramda';
import clsx from 'clsx';

export enum GridSizeEnum {
	'2xl' = '2xl',
	base = 'base',
	lg = 'lg',
	md = 'md',
	sm = 'sm',
	xl = 'xl',
}

export const { sm, md, lg, xl } = GridSizeEnum;

export enum GridVerticalAlignEnum {
	bottom = 'bottom',
	center = 'center',
	top = 'top',
}

export type GridProps = {
	children?: React.ReactNode;
	className?: string;
	cols?: Partial<Record<GridSizeEnum, number>>;
	gap?: number;
	vertical?: GridVerticalAlignEnum;
};

export const breakpointSizes = (type: string) =>
	compose(
		values,
		mapObjIndexed((size, breakpoint) => {
			if (breakpoint === GridSizeEnum.base) {
				return `${type}-${size}`;
			}
			return `${breakpoint}:${type}-${size}`;
		}),
	);

export const Grid: FC<GridProps> = ({ cols, gap = 1, className, children, vertical }) => {
	return (
		<div
			className={clsx(
				'grid',
				{
					'grid-cols-1': !cols?.[GridSizeEnum.base],
				},
				className,
				{
					'grid-items-start': vertical === GridVerticalAlignEnum.top,
					'grid-items-center': vertical === GridVerticalAlignEnum.center,
					'grid-items-end': vertical === GridVerticalAlignEnum.bottom,
				},
				breakpointSizes('grid-cols')(cols ?? {}),
				{
					[`gap-${gap}`]: gap,
				},
			)}>
			{children}
		</div>
	);
};
