import React, { FC } from 'react';
import clsx from 'clsx';

import { breakpointSizes, GridSizeEnum, GridVerticalAlignEnum } from './Grid';

type IGridColProps = {
	children?: React.ReactNode;
	className?: string;
	colSpan?: Partial<Record<GridSizeEnum, number>>;
	end?: Partial<Record<GridSizeEnum, number>>;
	rowSpan?: Partial<Record<GridSizeEnum, number>>;
	start?: Partial<Record<GridSizeEnum, number>>;
	vertical?: GridVerticalAlignEnum;
};

export const GridCol: FC<IGridColProps> = ({ start, end, colSpan, rowSpan, children, className, vertical }) => {
	return (
		<div
			className={clsx(
				className,
				'col-span-1 row-span-1',
				breakpointSizes('col-start')(start ?? {}),
				breakpointSizes('col-end')(end ?? {}),
				{
					'grid-col-start': vertical === GridVerticalAlignEnum.top,
					'grid-col-center': vertical === GridVerticalAlignEnum.center,
					'grid-col-end': vertical === GridVerticalAlignEnum.bottom,
				},
				breakpointSizes('col-span')(colSpan ?? {}),
				breakpointSizes('row-span')(rowSpan ?? {}),
			)}>
			{children}
		</div>
	);
};
