import React, { useEffect, useState } from 'react';

type IProps = {
	max: number;
	min: number;
	onChange?: (value: number, e: React.ChangeEvent) => void;
	value?: number;
};

const Slider: React.FC<IProps> = (props) => {
	const { max, min, onChange } = props;

	const [value, setValue] = useState(props.value);

	useEffect(() => {
		if (props.value !== value) {
			setValue(props.value);
		}
	}, [props.value]);

	const handleChange = (e: React.ChangeEvent<HTMLInputElement>): void => {
		if (onChange) {
			onChange(parseInt(e.currentTarget.value), e);
		}
		setValue(parseInt(e.currentTarget.value));
	};

	return (
		<>
			<input
				type="range"
				className="appearance-none w-full h-4 bg-gray-100 mb-3 rounded-lg"
				max={max}
				min={min}
				value={value}
				onChange={handleChange}
			/>
			{value} / {max}
		</>
	);
};

Slider.displayName = 'Slider';

export default Slider;
