import React, { FC, useMemo } from 'react';
import clsx from 'clsx';

import type { TableRow as TableRowType } from '../types';
import { TableCol } from '../types';
import { TableCell } from './TableCell';
import { TableHead } from './TableHead';
import TableRow from './TableRow';

export type TableProps = {
	className?: string;
	cols: TableCol;
	nthStyle?: boolean;
	rows: TableRowType[];
};

export const Table: FC<TableProps> = ({ cols, rows, nthStyle = true, className }) => {
	const body = useMemo(() => {
		if (!rows) {
			return null;
		}
		return rows.map((row, i) => (
			<TableRow nthStyle={nthStyle} key={i} className={row.className}>
				{Object.keys(cols.data).map((cell) => (
					<TableCell key={cell} title={cols.data[cell].value} className={row.data[cell].className}>
						{row.data[cell].value}
					</TableCell>
				))}
			</TableRow>
		));
	}, [cols.data, rows, nthStyle]);

	return (
		<div className={clsx('tablek', className)}>
			<div className="tablek-head-row">
				{Object.keys(cols.data).map((c) => (
					<TableHead key={c} className={cols.className}>
						{cols.data[c].value}
					</TableHead>
				))}
			</div>
			{body}
		</div>
	);
};
