import { useEffect, useState } from 'react';

export enum SIZES {
	lg = '1024px',
	md = '768px',
}

type Props = {
	size: SIZES;
};

const checkMinMatch = (size: SIZES): boolean => {
	const query = `(min-width: ${size})`;
	return window.matchMedia(query).matches;
};

const checkMaxMatch = (size: SIZES): boolean => {
	const query = `(max-width: ${size})`;
	return window.matchMedia(query).matches;
};

export const useMediaQuery = ({ size }: Props) => {
	const [isMinMatch, setIsMinMatch] = useState(false);
	const [isMaxMatch, setIsMaxMatch] = useState(false);

	const checkMatch = () => {
		setIsMinMatch(checkMinMatch(size));
		setIsMaxMatch(checkMaxMatch(size));
	};

	useEffect(() => {
		checkMatch();
		window.addEventListener('resize', checkMatch);
		return () => window.removeEventListener('resize', checkMatch);
	}, []);

	return {
		isMinMatch: isMinMatch ?? checkMinMatch(size),
		isMaxMatch: isMaxMatch ?? checkMaxMatch(size),
	};
};
