import path from 'path';

export default (config) => {
	config.module.rules.push({
		test: /\.(ts|tsx)$/,
		resourceQuery: /raw/,
		use: 'raw-loader',
		type: 'javascript/auto',
	});

	config.module.rules.push({
		test: /\.(ts|tsx)$/,
		use: {
			loader: 'ts-loader',
			options: {
				configFile: path.join(__dirname, './tsconfig.json'),
			},
		},
		exclude: /node_modules/,
		resourceQuery: { not: [/raw/] },
		include: [path.join(__dirname, '../packages'), path.join(__dirname, '../stories')],
	});

	config.module.rules.push({
		test: /\.css$/i,
		use: [
			{
				loader: 'postcss-loader',
				options: {
					postcssOptions: {
						config: __dirname + '/styles/postcss.config.js'
					}
				}
			}
		]
	});

	config.devtool = 'inline-source-map';

	config.resolve.extensions.push('.ts', '.tsx', '.mdx', '.json', '.txt', '.css');

	config.resolve.alias = {
		...config.resolve.alias,
		config: path.join(__dirname, '../config'),
		'@procyon/components': path.join(__dirname, '../packages/components/src'),
		'@procyon/api': path.join(__dirname, '../packages/api/src'),
		'@procyon/auth': path.join(__dirname, '../packages/auth/src'),
		'@procyon/constants': path.join(__dirname, '../packages/constants/src'),
		'@procyon/forms': path.join(__dirname, '../packages/forms/src'),
		'@procyon/hooks': path.join(__dirname, '../packages/hooks/src'),
		'@procyon/localization': path.join(__dirname, '../packages/localization/src'),
		'@procyon/router': path.join(__dirname, '../packages/router/src'),
		'@procyon/styles': path.join(__dirname, '../packages/styles/src'),
		'@procyon/types': path.join(__dirname, '../packages/types/src'),
		'@procyon/utils': path.join(__dirname, '../packages/utils/src'),
	};

	return config;
};
