import { BaseQueryApi } from '@reduxjs/toolkit/query';

import { isJSON } from '@procyon/utils';

import { setAuthAttributes } from './slice';
import { UseFetchTokensParams, UseReAuthFetchParams } from './types';

export const fetchTokens = async ({ baseUrl, tokenEndpoint, clientId, code, redirectUri }: UseFetchTokensParams) => {
	try {
		const response = await fetch(`${baseUrl}${tokenEndpoint}`, {
			method: 'post',
			headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
			body: new URLSearchParams({
				code,
				client_id: clientId,
				grant_type: 'authorization_code',
				redirect_uri: redirectUri,
			}),
		});
		const data = await response.text().then((text: string) => (isJSON(text) ? JSON.parse(text) : text));
		if (!response.ok) throw response;
		return { data };
	} catch (error) {
		return { error };
	}
};

export const renewAccessToken = async (
	{ baseUrl, clientId, tokenEndpoint, refreshToken }: UseReAuthFetchParams,
	api: BaseQueryApi,
) => {
	const response = await fetch(`${baseUrl}${tokenEndpoint}`, {
		method: 'post',
		headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
		body: new URLSearchParams({
			client_id: clientId,
			grant_type: 'refresh_token',
			refresh_token: refreshToken,
		}),
	});
	const data = await response.text().then((text: string) => (isJSON(text) ? JSON.parse(text) : text));
	if (!response.ok) throw response;
	api.dispatch(
		setAuthAttributes({
			accessToken: data.access_token,
			refreshToken: data.refresh_token,
			idToken: data.id_token,
			accessExpiresIn: data.expires_in,
			refreshExpiresIn: data.refresh_expires_in,
			sessionState: data.session_state,
		}),
	);
};
