import { createSlice, PayloadAction } from '@reduxjs/toolkit';

import { AuthAttributes, AuthRootState, ModifyAuthAttributePayload } from './types';

const initialState: AuthAttributes = {
	authenticated: undefined,
	accessToken: undefined,
	refreshToken: undefined,
};

export const slice = createSlice({
	name: 'auth',
	initialState,
	reducers: {
		setAuthAttributes: (state, action: PayloadAction<AuthAttributes<any>>) => ({
			...state,
			...action.payload,
		}),
		updateAuthAttribute: {
			prepare: (key, value) => ({
				payload: { key, value },
			}),
			reducer: (state, action: PayloadAction<ModifyAuthAttributePayload>) => {
				state[action.payload.key] = action.payload.value;
			},
		},
		deleteAuthAttributes: () => initialState,
	},
});

export const { deleteAuthAttributes } = slice.actions;

export const setAuthAttributes = slice.actions.setAuthAttributes as <T>(
	attrs: AuthAttributes<T>,
) => PayloadAction<AuthAttributes<T>>;

export const updateAuthAttribute = slice.actions.updateAuthAttribute as <T>(
	key: keyof AuthAttributes<T>,
	value: unknown,
) => PayloadAction<ModifyAuthAttributePayload<T>>;

export const getAuthAttributes = <T>(state: AuthRootState<T>) => state.procyon.auth as AuthAttributes<T>;
