import React, { ReactNode } from 'react';
import clsx from 'clsx';

import { SizeEnum, StatusEnum } from '@procyon/types/enums';

export type ButtonProps = {
	blank?: boolean;
	className?: string;
	disabled?: boolean;
	label: string | ReactNode;
	onClick?: (e?: any) => void | Promise<void>;
	size?: Exclude<SizeEnum, 'xl'>;
	status?: StatusEnum;
	type?: 'submit' | 'reset' | 'button';
};

export const Button: React.FC<ButtonProps> = (props) => {
	const {
		disabled,
		onClick,
		status = StatusEnum.none,
		size = SizeEnum.md,
		label,
		type = 'button',
		className,
		blank = false,
	} = props;

	const handleOnClick = () => {
		if (onClick) {
			setTimeout(() => {
				onClick();
			}, 100);
		}
	};

	return (
		<button
			className={clsx(
				'button',
				{
					'button--large': size === SizeEnum.lg,
					'button--medium': size === SizeEnum.md,
					'button--small': size === SizeEnum.sm,
					'button--blank': blank,
					'button--none': status === StatusEnum.none,
					'button--info': status === StatusEnum.info,
					'button--success': status === StatusEnum.success,
					'button--warning': status === StatusEnum.warning,
					'button--error': status === StatusEnum.error,
				},
				className
			)}
			onClick={handleOnClick}
			disabled={disabled}
			type={type}>
			{label}
		</button>
	);
};
