import React, { FC, useMemo } from 'react';
import { format } from 'date-fns';

import { AngleLeftIcon } from '@procyon/components/Icons/AngleLeft';
import { AngleRightIcon } from '@procyon/components/Icons/AngleRight';
import { TodayIcon } from '@procyon/components/Icons/Today';

import { CalendarLayoutEnum, CalendarTypeEnum, getWeekRange } from './Calendar';

export type ControllerProps = {
	layout: CalendarLayoutEnum;
	onNextClick: () => void;
	onPrevClick: () => void;
	onTodayClick: () => void;
	type: CalendarTypeEnum;
	workDate: Date;
};

export const Controller: FC<ControllerProps> = ({ layout, type, workDate, onNextClick, onPrevClick, onTodayClick }) => {
	const Controller = useMemo(() => {
		switch (layout) {
			case CalendarLayoutEnum.month:
				if (type === CalendarTypeEnum.months) {
					return format(workDate, 'yyyy');
				}
				return format(workDate, 'MM. yyyy');
			case CalendarLayoutEnum.week:
				return [format(getWeekRange(workDate)[0], 'dd.MM.'), ' - ', format(getWeekRange(workDate)[1], 'dd.MM.yyyy')];
			case CalendarLayoutEnum.day:
				return format(workDate, 'dd.MM.yyyy');
		}
	}, [workDate, layout, type]);

	return (
		<div className="calendar-controller">
			<div className="inline-block cursor-pointer pl-2" onClick={onPrevClick}>
				<AngleLeftIcon />
			</div>
			<div className="inline-block px-5">{Controller}</div>
			<div className="inline-block cursor-pointer pr-4" onClick={onNextClick}>
				<AngleRightIcon />
			</div>
			<div className="inline-block cursor-pointer text-md" onClick={onTodayClick}>
				<TodayIcon />
			</div>
		</div>
	);
};
