import React, { FC, ReactNode, useState } from 'react';

import { Button, ButtonProps } from '@procyon/components/Button';
import { ButtonGroup } from '@procyon/components/ButtonGroup';
import { AngleDownIcon } from '@procyon/components/Icons/AngleDown';
import { AngleUpIcon } from '@procyon/components/Icons/AngleUp';

export type DropdownButtons = {
	onClose: () => void;
};

export type DropdownProps = {
	Buttons?: FC<DropdownButtons>;
	MainButton: ReactNode;
	size?: ButtonProps['size'];
};

export const Dropdown: FC<DropdownProps> = ({ Buttons, MainButton, size }) => {
	const [toggled, setToggled] = useState(false);

	const handleClose = () => {
		setToggled(false);
	};

	return (
		<>
			<ButtonGroup>
				{MainButton}
				{Buttons && (
					<Button
						className="w-14"
						label={toggled ? <AngleUpIcon /> : <AngleDownIcon />}
						onClick={() => setToggled(!toggled)}
						{...(size ? { size } : {})}
					/>
				)}
			</ButtonGroup>
			<div className="absolute left-2 right-2 bg-white">
				{Buttons && toggled && <Buttons onClose={() => handleClose()} />}
			</div>
		</>
	);
};
