import React, { FC, ReactNode } from 'react';
import clsx from 'clsx';

import { StatusEnum } from '@procyon/types/enums';

import { CheckCircleIcon } from './Icons/CheckCircle';
import { ErrorIcon } from './Icons/ExclamationCircle';
import { ExclamationTriangleIcon } from './Icons/ExclamationTriangle';
import { InfoCircleIcon } from './Icons/InfoCircle';

export type MessageProps = {
	children?: ReactNode;
	className?: string;
	status: StatusEnum;
	title?: string;
};

export const Message: FC<MessageProps> = ({ status = StatusEnum.none, title, children, className }) => (
	<div
		className={clsx('message', className, {
			'message--none': status === StatusEnum.none,
			'message--info': status === StatusEnum.info,
			'message--success': status === StatusEnum.success,
			'message--warning': status === StatusEnum.warning,
			'message--error': status === StatusEnum.error
		})}>
		<div>
			{status === StatusEnum.info && <InfoCircleIcon />}
			{status === StatusEnum.success && <CheckCircleIcon />}
			{status === StatusEnum.warning && <ExclamationTriangleIcon />}
			{status === StatusEnum.error && <ErrorIcon />}
			{status === StatusEnum.none && <InfoCircleIcon />}
		</div>
		<div className="max-w-full">
			<div>
				{title && <div className="text-lg mb-1">{title}</div>}
				<div className="text-sm">{children}</div>
			</div>
		</div>
	</div>
);
