import React, { useEffect, useState } from 'react';

import { ButtonCursorIcon } from '@procyon/components/Icons/ButtonCursor';
import { useModal } from '@procyon/components/Modal/useModal';
import { InputElementType } from '@procyon/types/form';
import { Option } from '@procyon/types/options';

import { TextField } from '../TextField';
import { SelectboxModal } from './components/SelectboxModal';

export type SelectBoxProps<V = Option['code']> = Omit<
	{
		autoComplete?: boolean;
		options: Option[];
	} & InputElementType<V>,
	'onFocus' | 'onClick' | 'onBlur'
>;

export const Selectbox: React.FC<SelectBoxProps> = (props) => {
	const { value, options, onChange, name, label, autoComplete, ...others } = props;

	const [openModal, closeModal] = useModal(name, {
		title: label,
		style: { width: 300 },
		Component: (props: object) => (
			<SelectboxModal
				autoComplete={autoComplete}
				name={name}
				options={options}
				closeModal={closeModal}
				onChange={handleOptionClick}
				onRemove={handleOptionRemove}
				selectedCode={selectedOption?.code}
				{...props}
			/>
		),
	});

	const [selectedOption, setSelectedOption] = useState<Option | null>(null);

	useEffect(() => {
		if (value !== selectedOption?.code) {
			const newValue = options?.find(({ code }) => code === value) ?? null;
			setSelectedOption(newValue);
		}
	}, [value, options]);

	const handleOptionClick = (option: Option) => {
		setSelectedOption(option);
		onChange?.(option?.code, null);
	};

	const handleOptionRemove = () => {
		setSelectedOption(null);
		onChange?.(undefined, null);
	};

	const handleOpenModal = () => {
		openModal();
	};

	return (
		<TextField
			{...others}
			readonly
			name={name}
			label={label}
			value={selectedOption?.name}
			leftIcon={<ButtonCursorIcon className="field-icon" onClick={handleOpenModal} />}
		/>
	);
};
