import React, { FC } from 'react';

import { GridCol } from '@procyon/components/GridCol';
import { TrashIcon } from '@procyon/components/Icons/Trash';
import List from '@procyon/components/List';
import { SizeEnum, StatusEnum } from '@procyon/types/enums';
import { Option } from '@procyon/types/options';

import { Button } from '../../Button';
import { Grid, GridSizeEnum } from '../../Grid';
import { ModalId } from '../../Modal/context';

export type SelectboxModalProps = {
	autoComplete?: boolean;
	closeModal: () => void;
	name: ModalId;
	onChange: (options: Option) => void;
	onRemove: () => void;
	options: Option[];
	selectedCode?: Option['code'];
};

const { md } = GridSizeEnum;

export const SelectboxModal: FC<SelectboxModalProps> = (props) => {
	const { name, options, autoComplete, selectedCode, onChange, onRemove, closeModal } = props;

	const handleChange = (option: Option) => {
		onChange(option);
		closeModal();
	};

	const removeActiveOption = (): void => {
		onRemove();
		closeModal();
	};

	return (
		<div>
			<List
				name={name}
				options={options}
				autoComplete={autoComplete}
				selectedCode={selectedCode}
				onChange={handleChange}
			/>
			<Grid cols={{ [md]: 3 }}>
				<GridCol start={{ [md]: 3 }} end={{ [md]: 3 }}>
					<Button
						label={<TrashIcon fontSize={20} />}
						size={SizeEnum.sm}
						status={StatusEnum.warning}
						onClick={removeActiveOption}
						blank
					/>
				</GridCol>
			</Grid>
		</div>
	);
};
