import React from 'react';
import clsx from 'clsx';

import { ExternalIcon } from '@procyon/components/Icons/External';

import { MenuItem } from '../types';

type IProps = {
	className?: string;
	collapsed?: boolean;
	item: MenuItem;
	onClick: (item: MenuItem) => void;
};

export const Item = (props: IProps) => {
	const {
		onClick,
		item,
		item: { icon, external },
		className,
		collapsed
	} = props;

	const handleOnClick = () => {
		onClick(item);
	};

	return (
		<div className={clsx('menu-container', className)}>
			<div
				className={clsx('menu-item', {
					'menu-item--active': item?.isActive?.()
				})}
				onClick={handleOnClick}>
				{icon && (
					<div
						className={clsx('text-2xl menu-item-icon', {
							'menu-item-icon-only': !item.label
						})}>
						{icon}
					</div>
				)}
				<div
					className={clsx({
						'menu-item-tooltip': collapsed
					})}>
					{item.label}
				</div>
				{external && (
					<div className="ml-2">
						<ExternalIcon />
					</div>
				)}
			</div>
		</div>
	);
};

export default MenuItem;
