import React, { useMemo } from 'react';

import List from '@procyon/components/List';
import { Option } from '@procyon/types/options';

export type TimeListProps = {
	max: number;
	min: number;
	name: string;
	onChange: (code: Option['code']) => void;
	scrollToCode?: Option['code'];
	selectedCode?: Option['code'];
	step: number;
	title?: string;
	value?: string;
};

const TimeList: React.FC<TimeListProps> = ({ title, onChange, min, max, step, selectedCode, scrollToCode, name }) => {
	const handleChange = (option: Option) => {
		onChange(option.code);
	};

	const options = useMemo(() => {
		const _options: Option[] = [];
		for (let i = min; i <= max; i = i + step) {
			_options.push({
				code: i,
				name: ('0' + i).slice(-2),
			});
		}
		return _options;
	}, [step, min, max]);

	return (
		<>
			{title ?? null}
			<List
				name={name}
				options={options}
				onChange={handleChange}
				compact
				selectedCode={selectedCode}
				scrollToCode={scrollToCode}
				enableAutoScroll
				className="h-60 text-center"
			/>
		</>
	);
};

export default TimeList;
