import React from 'react';
import clsx from 'clsx';

import { isNilOrEmpty } from '@procyon/utils';

import { Message } from '../../Message';
import { useToaster } from '../hooks';

export enum ToastersPosition {
	BottomCenter = 'bottomCenter',
	BottomLeft = 'bottomLeft',
	BottomRight = 'bottomRight',
	LeftCenter = 'leftCenter',
	RightCenter = 'rightCenter',
	TopCenter = 'topCenter',
	TopLeft = 'topLeft',
	TopRight = 'topRight',
}

export type ToastersProps = {
	position: ToastersPosition;
};

export function Toasters({ position }) {
	const { toasters } = useToaster();

	if (isNilOrEmpty(toasters)) {
		return null;
	}

	return (
		<div
			className={clsx('toasters', {
				'toasters--topLeft': ToastersPosition.TopLeft === position,
				'toasters--topCenter': ToastersPosition.TopCenter === position,
				'toasters--topRight': ToastersPosition.TopRight === position,
				'toasters--rightCenter': ToastersPosition.RightCenter === position,
				'toasters--bottomRight': ToastersPosition.BottomRight === position,
				'toasters--bottomCenter': ToastersPosition.BottomCenter === position,
				'toasters--bottomLeft': ToastersPosition.BottomLeft === position,
				'toasters--leftCenter': ToastersPosition.LeftCenter === position,
			})}>
			{Object.keys(toasters).map((toasterId) => {
				const toaster = toasters[toasterId];
				return (
					<Message key={toasterId} status={toaster.status} title={toaster.title}>
						{toaster.message}
					</Message>
				);
			})}
		</div>
	);
}
