import React from 'react';
import { always } from 'ramda';
import {
	FieldValues,
	FormProvider,
	SubmitErrorHandler,
	SubmitHandler,
	UseFormHandleSubmit,
	UseFormReturn,
} from 'react-hook-form';

import { Nullable } from '@procyon/types';
import { noop } from '@procyon/utils';

type N<FD> = Nullable<Partial<FD>>;

export type FormProps<FD extends FieldValues> = {
	children: React.ReactElement;
	methods: Omit<UseFormReturn<N<FD>>, 'handleSubmit'> & { handleSubmit: UseFormHandleSubmit<FD, any> };
	onFail?: SubmitErrorHandler<FD>;
	onSubmit: SubmitHandler<FD>;
};

export function Form<FD extends FieldValues>(props: Readonly<FormProps<FD>>) {
	const { onSubmit, onFail = always(noop), methods } = props;
	return (
		<FormProvider {...methods}>
			<form onSubmit={methods.handleSubmit(onSubmit, onFail)}>{props.children}</form>
		</FormProvider>
	);
}
