import { yupResolver } from '@hookform/resolvers/yup';
import * as rhf from 'react-hook-form';
import { ObjectSchema } from 'yup';

import { Nullable } from '@procyon/types';

type N<FD> = Nullable<Partial<FD>>;

export type FormOptions<FD extends rhf.FieldValues> = {
	schema: ObjectSchema<N<FD>>;
} & rhf.UseFormProps<N<FD>>;

export type UseFormReturnType<FD extends rhf.FieldValues> = Omit<rhf.UseFormReturn<N<FD>>, 'handleSubmit'> & {
	handleSubmit: rhf.UseFormHandleSubmit<FD | N<FD>, any>;
};

export const useForm = <FD extends rhf.FieldValues>(options: FormOptions<N<FD>>): UseFormReturnType<FD> => {
	return rhf.useForm<N<FD>>({
		...options,
		resolver: yupResolver<N<FD>>(options.schema) as never,
	});
};

export default rhf;
