import { DotNestedKeys } from '@procyon/types';

import { lang } from './init';
import { Dictionary } from './types';

export function t<D>(key: DotNestedKeys<Dictionary & D>, variables?: Record<string, any>) {
	// get locale from settings
	const locale = lang.getLocale();
	if (!locale) {
		return false;
	}

	// resolve message value
	const resource = lang.getLocaleResource(locale);
	let message = (key as any).split('.').reduce((previous, current) => previous[current], resource);
	if (!message) {
		return false;
	}

	// resolve variables
	Object.keys(variables ?? {}).forEach((name) => {
		const value = variables?.[name];
		let replaceWith = null;

		// resolve pluralization
		const absValue = Math.abs(value);
		if (!isNaN(absValue)) {
			if (absValue === 1) {
				replaceWith = t(`${name}` as never);
			}
			if (absValue >= 2 && absValue <= 4) {
				replaceWith = t(`${name}_2` as never);
			}
			if (absValue === 0 || absValue >= 5) {
				replaceWith = t(`${name}_5` as never);
			}
		}

		// resolve final value for replace
		if (!replaceWith) {
			replaceWith = value;
		}

		// make final version of message
		message = message.replaceAll(`{{${name}}}`, replaceWith);
	});

	// return result
	return message;
}
