import React from 'react';
import type { Meta, StoryObj } from '@storybook/react';

import { Button } from '@procyon/components/Button';
import { ButtonGroup } from '@procyon/components/ButtonGroup';
import { SizeEnum, StatusEnum } from '@procyon/types/enums';

type Story = StoryObj<typeof ButtonGroup>;

export default {
	component: ButtonGroup,
	parameters: {
		docs: {
			description: {
				component: "`import { ButtonGroup } from '@procyon/components/ButtonGroup';`",
			},
		},
	},
	decorators: [
		(Story) => {
			return (
				<ButtonGroup>
					<Story />
				</ButtonGroup>
			);
		},
	],
	tags: ['autodocs'],
} as Meta;

export const Default: Story = {
	args: {},
	render: () => (
		<>
			<Button label="Button A" />
			<Button label="Button B" />
			<Button label="Button C" />
		</>
	),
};

export const OneDisabled: Story = {
	args: {},
	render: () => (
		<>
			<Button label="Button A" />
			<Button label="Button B" disabled />
			<Button label="Button C" />
		</>
	),
};

export const DifferentStates: Story = {
	args: {},
	render: () => (
		<>
			<Button label="Button A" status={StatusEnum.warning} />
			<Button label="Button B" status={StatusEnum.success} />
			<Button label="Button C" status={StatusEnum.info} />
		</>
	),
};

export const Small: Story = {
	args: {},
	decorators: [
		(Story) => (
			<div className={'w-10'}>
				<ButtonGroup>
					<Story />
				</ButtonGroup>
			</div>
		),
	],
	render: () => (
		<>
			<Button label={<span>E</span>} status={StatusEnum.none} size={SizeEnum.sm} />
			<Button label={<span>U</span>} status={StatusEnum.none} size={SizeEnum.sm} />
			<Button label={<b>D</b>} status={StatusEnum.error} size={SizeEnum.sm} />
		</>
	),
};
