import React from 'react';
import { action } from '@storybook/addon-actions';
import type { StoryObj } from '@storybook/react';

import { Calendar } from '@procyon/components/Calendar';
import { CalendarLayoutEnum, CalendarTypeEnum } from '@procyon/components/Calendar/components/Calendar';

import { MonthView } from './Calendar/MonthView';
import { TimeColumn } from './Calendar/TimeColumn';
import { WeekView } from './Calendar/WeekView';

type Story = StoryObj<typeof Calendar>;

export default {
	component: Calendar,
	parameters: {
		docs: {
			description: {
				component: "`import Calendar from '@procyon/components/Calendar';`",
			},
		},
	},
	tags: ['autodocs'],
};

export const SmallCalendar: Story = {
	args: {
		selected: new Date(new Date().setDate(new Date().getDate() + 1)),
		enableHover: true,
	},
};

export const WeekCalendar: Story = {
	args: {
		selected: new Date(new Date().setDate(new Date().getDate() + 1)),
		View: (props) => <WeekView {...props} />,
		TimeColumn: TimeColumn,
		layout: CalendarLayoutEnum.week,
		onClick: () => action('on day change'),
		onRangeChange: action('on range change'),
		enableHover: true,
	},
};

export const MonthCalendar: Story = {
	args: {
		title: 'Month calendar',
		View: MonthView,
		selected: new Date(new Date().setDate(new Date().getDate() + 1)),
		layout: CalendarLayoutEnum.month,
		enableHover: true,
	},
};

export const DayWeekCalendar: Story = {
	args: {
		title: 'Day Week calendar',
		selected: new Date(new Date().setDate(new Date().getDate() + 10)),
		enableHover: true,
		type: CalendarTypeEnum.weeks,
	},
};

export const MonthTypeCalendar: Story = {
	args: {
		title: 'Month type calendar',
		selected: new Date(new Date().setMonth(new Date().getMonth() + 1)),
		enableHover: true,
		type: CalendarTypeEnum.months,
	},
};
