import React, { FC, useMemo } from 'react';
import { times } from 'ramda';
import clsx from 'clsx';
import { addMinutes, format } from 'date-fns';

import { CalendarCellProps } from '@procyon/components/Calendar/components/CalendarCell';

import { HourView } from './HourView';

export const WeekView: FC<CalendarCellProps> = ({ date, onClick, enableHover }) => {
	const handleClick = (index: number) => {
		if (onClick && date) {
			const dateTime = addMinutes(date.setHours(8, 0, 0, 0), 30 * index);
			onClick(dateTime);
		}
	};

	const agenda = useMemo(() => {
		return times((i) => {
			if (Math.round(Math.random())) {
				return (
					<HourView
						key={i}
						onClick={() => handleClick(i)}
						className={clsx({
							'hover:bg-focus-100': enableHover,
						})}
					/>
				);
			} else {
				return (
					<HourView key={i} className="text-left">
						<div className="bg-primary-200 text-white h-full p-1">event</div>
					</HourView>
				);
			}
		}, 16);
	}, [enableHover]);

	return (
		<div className="calendar-cell">
			{date ? format(date, 'dd') : null}
			{agenda}
		</div>
	);
};
