import React from 'react';
import type { Meta, StoryObj } from '@storybook/react';

import { Button } from '@procyon/components/Button';
import { Dropdown } from '@procyon/components/Dropdown';
import { SizeEnum, StatusEnum } from '@procyon/types/enums';

type Story = StoryObj<typeof Dropdown>;

export default {
	component: Dropdown,
	argTypes: {
		MainButton: {
			control: { type: 'text' },
		},
		Buttons: {
			control: { type: 'text' },
		},
	},
	parameters: {
		docs: {
			description: {
				component: "`import { Dropdown } from '@procyon/components/Dropdown';`",
			},
		},
	},
	decorators: [
		(Story) => (
			<div className="h-40">
				<Story />
			</div>
		),
	],
	tags: ['autodocs'],
} as Meta;

export const Default: Story = {
	args: {
		MainButton: <Button label={'Main action'} />,
		Buttons: ({ onClose }) => {
			return (
				<>
					<Button label="Button A" onClick={() => onClose()} />
					<Button label="Button B" onClick={() => onClose()} status={StatusEnum.error} />
				</>
			);
		},
	},
};

export const WithoutButtons: Story = {
	args: {
		MainButton: <Button label={'Main action'} />,
	},
};

export const Small: Story = {
	args: {
		size: SizeEnum.sm,
		MainButton: <Button size={SizeEnum.sm} label={'Main action'} />,
		Buttons: ({ onClose }) => {
			return (
				<>
					<Button label="Button A" onClick={() => onClose()} />
					<Button label="Button B" onClick={() => onClose()} status={StatusEnum.error} />
				</>
			);
		},
	},
};
