import React from 'react';
import { Meta, StoryObj } from '@storybook/react';
import { Route } from 'wouter';

import { DashboardIcon } from '@procyon/components/Icons/Dashboard';
import { SettingsIcon } from '@procyon/components/Icons/Settings';
import { UserIcon } from '@procyon/components/Icons/User';
import { Skeleton } from '@procyon/components/Skeleton';

const Routes = () => (
	<>
		<Route path="/r1">
			<div>Conten 1</div>
		</Route>
		<Route path="/r2">
			<div>Conten 2</div>
		</Route>
	</>
);

type Story = StoryObj<typeof Skeleton>;

const items = {
	logo: <div>procyon</div>,
	side: [
		{ label: 'Dashboard', href: '/r1', icon: <DashboardIcon /> },
		{
			label: 'Uživatelé',
			href: '/r2'
		},
		{
			label: 'Skupiny',
			href: '/r3'
		}
	],
	top: [
		{ label: 'Dashboard', href: '/r1', icon: <DashboardIcon /> },
		{
			label: 'Uživatelé',
			href: '/r2'
		},
		{
			label: 'Skupiny',
			href: '/r3'
		},
		{
			label: 'Menu External',
			href: 'https://procyon.romanjaros.dev',
			external: true
		}
	],
	user: [
		{ label: null, icon: <SettingsIcon /> },
		{
			label: 'Profil',
			icon: <UserIcon />
		}
	]
};

export default {
	component: Skeleton,
	parameters: {
		docs: {
			description: {
				component: "`import { Skeleton } from '@procyon/components/Skeleton';`"
			}
		}
	},
	tags: ['autodocs']
} as Meta;

export const Default: Story = {
	args: {
		children: <Routes />,
		items: items
	}
};

export const TopPanel: Story = {
	args: {
		children: <Routes />,
		items: {
			...items,
			side: undefined
		}
	}
};

export const SidePanel: Story = {
	args: {
		children: <Routes />,
		items: {
			...items,
			top: undefined
		}
	}
};

export const JustContent: Story = {
	args: {
		children: (
			<>
				Hello <Routes />
			</>
		),
		items: {}
	}
};
