import React from 'react';
import { Meta, StoryObj } from '@storybook/react';

import { AngleRightIcon } from '@procyon/components/Icons/AngleRight';
import { Table } from '@procyon/components/Table';

type Story = StoryObj<typeof Table>;

export default {
	component: Table,
	parameters: {
		docs: {
			description: {
				component: "`import { Table } from '@procyon/components/Table';`"
			}
		}
	},
	tags: ['autodocs']
} as Meta<typeof Table>;

export const Default: Story = {
	args: {
		cols: {
			data: {
				company: { value: 'Company' },
				contact: { value: 'Contact' },
				country: { value: 'Country' },
				action: { value: '' }
			}
		},
		rows: [
			{
				data: {
					company: { value: 'Centro comercial Moctezuma' },
					contact: { value: 'Francisco Chang' },
					country: { value: 'Mexico' },
					action: { component: <AngleRightIcon /> }
				}
			},
			{
				data: {
					company: { value: 'Alfreds Futterkiste' },
					contact: { value: 'Maria Anders' },
					country: { value: 'Germany' },
					action: { component: <AngleRightIcon /> }
				}
			},
			{
				data: {
					company: { value: 'Centro comercial Moctezuma' },
					contact: { value: 'Francisco Chang' },
					country: { value: 'Mexico' },
					action: { component: <AngleRightIcon /> }
				}
			},
			{
				data: {
					company: { value: 'Alfreds Futterkiste' },
					contact: { value: 'Maria Anders' },
					country: { value: 'Germany' },
					action: { component: <AngleRightIcon /> }
				}
			},
			{
				data: {
					company: { value: 'Centro comercial Moctezuma' },
					contact: { value: 'Francisco Chang' },
					country: { value: 'Mexico' },
					action: { component: <AngleRightIcon /> }
				}
			}
		]
	}
};

export const Withoutnth: Story = {
	args: {
		nthStyle: false,
		cols: {
			data: {
				company: { value: 'Company' },
				contact: { value: 'Contact' },
				country: { value: 'Country' },
				action: { value: '' }
			}
		},
		rows: [
			{
				data: {
					company: { value: 'Alfreds Futterkiste' },
					contact: { value: 'Maria Anders' },
					country: { value: 'Germany' },
					action: { component: <AngleRightIcon /> }
				}
			},
			{
				data: {
					company: { value: 'Centro comercial Moctezuma' },
					contact: { value: 'Francisco Chang' },
					country: { value: 'Mexico' },
					action: { component: <AngleRightIcon /> }
				}
			}
		]
	}
};

export const WithClass: Story = {
	args: {
		className: 'w-1/2',
		cols: {
			data: {
				company: { value: 'Company' },
				contact: { value: 'Contact' },
				country: { value: 'Country' },
				action: { value: '' }
			}
		},
		rows: [
			{
				data: {
					company: { value: 'Alfreds Futterkiste' },
					contact: { value: 'Maria Anders' },
					country: { value: 'Germany' },
					action: { component: <AngleRightIcon /> }
				}
			},
			{
				data: {
					company: { value: 'Centro comercial Moctezuma' },
					contact: { value: 'Francisco Chang' },
					country: { value: 'Mexico' },
					action: { component: <AngleRightIcon /> }
				}
			}
		]
	}
};

export const WithSpecificClassForRow: Story = {
	args: {
		nthStyle: false,
		cols: {
			data: {
				company: { value: 'Company' },
				contact: { value: 'Contact' },
				country: { value: 'Country' },
				action: { value: '' }
			}
		},
		rows: [
			{
				className: 'bg-purple-300',
				data: {
					company: { value: 'Alfreds Futterkiste' },
					contact: { value: 'Maria Anders' },
					country: { value: 'Germany' },
					action: { component: <AngleRightIcon /> }
				}
			},
			{
				className: 'bg-green-300',
				data: {
					company: { value: 'Centro comercial Moctezuma' },
					contact: { value: 'Francisco Chang' },
					country: { value: 'Mexico' },
					action: { component: <AngleRightIcon /> }
				}
			}
		]
	}
};

export const WithSpecificClassForCell: Story = {
	args: {
		nthStyle: false,
		cols: {
			data: {
				company: { value: 'Company' },
				contact: { value: 'Contact' },
				country: { value: 'Country' },
				action: { value: '' }
			}
		},
		rows: [
			{
				data: {
					company: { value: 'Alfreds Futterkiste', className: 'bg-purple-300' },
					contact: { value: 'Maria Anders' },
					country: { value: 'Germany' },
					action: { component: <AngleRightIcon /> }
				}
			},
			{
				data: {
					company: { value: 'Centro comercial Moctezuma' },
					contact: { value: 'Francisco Chang' },
					country: { value: 'Mexico' },
					action: { component: <AngleRightIcon /> }
				}
			}
		]
	}
};
