import { Meta, StoryObj } from '@storybook/react';

import { TextField } from '@procyon/components/TextField';
import { StatusEnum } from '@procyon/types/enums';

type Story = StoryObj<typeof TextField>;

export default {
	component: TextField,
	parameters: {
		docs: {
			description: {
				component: "`import TextField from '@procyon/components/TextField';`",
			},
		},
	},
	tags: ['autodocs'],
} as Meta<typeof TextField>;

export const Default: Story = {
	args: {
		name: 'field',
		label: 'TextField',
	},
};

export const WithoutLabel: Story = {
	args: {
		name: 'field',
		value: 'Value',
	},
};

export const WithoutLabelAndDisabled: Story = {
	args: {
		name: 'field',
		value: 'Value',
		disabled: true,
	},
};

export const DisabledWithValue: Story = {
	args: {
		name: 'field',
		label: 'Disabled with value',
		value: 'Value',
		disabled: true,
	},
};

export const DisabledWithoutValue: Story = {
	args: {
		name: 'field',
		label: 'Disabled without value',
		disabled: true,
	},
};

export const StatusError: Story = {
	args: {
		name: 'error',
		label: 'Error',
		value: ':-(',
		status: StatusEnum.error,
	},
};

export const StatusWarning: Story = {
	args: {
		name: 'warning',
		label: 'Warning',
		value: ':-O',
		status: StatusEnum.warning,
	},
};

export const StatusInformation: Story = {
	args: {
		name: 'info',
		label: 'Information',
		value: ';-)',
		status: StatusEnum.info,
	},
};

export const StatusSuccess: Story = {
	args: {
		name: 'success',
		label: 'Success',
		value: ':-)',
		status: StatusEnum.success,
	},
};

export const WithMask: Story = {
	args: {
		name: 'withMask',
		label: 'With mask',
		mask: '999 99',
		value: '11111',
	},
};

export const Multiline: Story = {
	args: {
		name: 'field',
		label: 'TextField',
		value: 'a\nv\nd',
		multiline: true,
	},
};
