import React from 'react';
import { Meta, StoryObj } from '@storybook/react';
import { setHours } from 'date-fns';

import Modals from '@procyon/components/Modal/components/Modals';
import { ModalWrapper } from '@procyon/components/Modal/context';
import { TimePicker } from '@procyon/components/TimePicker';

type Story = StoryObj<typeof TimePicker>;

const description = ` \`import TimePicker from '@procyon/components/TimePicker';\`

You need to wrap this component with \`ModalWrapper\` component.
`;

export default {
	component: TimePicker,
	parameters: {
		docs: {
			description: {
				component: description,
			},
		},
	},
	tags: ['autodocs'],
	decorators: [
		(Story) => (
			<div style={{ height: '600px' }}>
				<ModalWrapper>
					<Story />
					<Modals />
				</ModalWrapper>
			</div>
		),
	],
} as Meta<typeof TimePicker>;

const date = new Date();

export const Default: Story = {
	args: {
		name: 'timePicker1',
		label: 'Choose time',
		value: setHours(date, 20),
	},
};

export const WithoutLabel: Story = {
	args: {
		name: 'timePicker2',
		value: setHours(date, 20),
	},
};

export const RestrictedTimes: Story = {
	args: {
		name: 'timePicker3',
		label: 'Choose time',
		value: setHours(date, 20),
		minute: {
			step: 5,
			min: 0,
			max: 59,
		},
		hour: {
			step: 1,
			min: 8,
			max: 17,
		},
	},
};
