import React from 'react';
import { Meta, StoryObj } from '@storybook/react';

import { Button } from '@procyon/components/Button';
import { Toasters } from '@procyon/components/Toaster';
import { ToastersPosition } from '@procyon/components/Toaster/components/Toasters';
import { showToaster, ToasterWrapper } from '@procyon/components/Toaster/context';
import { useToaster } from '@procyon/components/Toaster/hooks';
import { StatusEnum } from '@procyon/types/enums';

type Story = StoryObj<typeof Toasters>;

export default {
	component: Toasters,
	argTypes: {
		position: {
			options: [
				ToastersPosition.TopLeft,
				ToastersPosition.TopCenter,
				ToastersPosition.TopRight,
				ToastersPosition.RightCenter,
				ToastersPosition.BottomLeft,
				ToastersPosition.BottomCenter,
				ToastersPosition.BottomRight,
				ToastersPosition.LeftCenter,
			],
			control: { type: 'radio' },
		},
	},
	decorators: [
		(Story) => (
			<div className="h-80">
				<ToasterWrapper>
					<Story />
				</ToasterWrapper>
			</div>
		),
	],
} as Meta;

export const Hook: Story = {
	name: 'Hook',
	render: (args) => {
		const Comp = () => {
			const { showToaster } = useToaster();
			return (
				<Button
					label="Open Toaster message"
					onClick={() =>
						showToaster({
							id: 'toaster1',
							title: 'Text',
							message: 'Message',
							status: StatusEnum.info,
						})
					}
				/>
			);
		};
		return (
			<>
				<Comp />
				<Toasters {...args} />
			</>
		);
	},
};

export const OutsideReact: Story = {
	name: 'Function',
	render: (args) => {
		return (
			<>
				<Button
					label="Open Toaster message"
					onClick={() =>
						showToaster({
							id: 'toaster2',
							title: 'Text',
							message: 'Message',
							status: StatusEnum.success,
						})
					}
				/>
				<Toasters {...args} />
			</>
		);
	},
};
